@@ -26,7 +26,7 @@ class Selenium(Scraper):
 
         options.add_argument('--no-sandbox')
         options.add_argument('--disable-dev-shm-usage')
-        options.addArguments('--start-maximized')
+        options.add_arguments('--start-maximized')
         self.driver = webdriver.Remote(command_executor='http://selenium:4443/wd/hub', desired_capabilities={'browserName': 'chrome'}, options=options)
 
         # #region undetected_chromedriver
